import { OperatorFunction, SrcOptions } from './models';
export declare class ImageProcess {
    private base64;
    private options;
    constructor(base64: string, options: SrcOptions);
    /**
     * Used to stitch together functional operators into a chain.
     * @method pipe
     * @returns Processed base64 string
     *
     * ### Example
     * ```ts
     * import { imageProcessor, pipe, resize } from 'ts-image-processor';
     *
     * imageProcessor.src(myBase64String)
     *   .pipe(
     *     resize({maxWidth: 800, maxHeight: 800}),
     *     sharpen(),
     *   )
     *   .then(processedBase64 => {
     *     // Do whatever
     *   });
     * ```
     */
    pipe(...operations: OperatorFunction[]): Promise<string>;
}
